@@ -1,4 +1,4 @@
 from .mvnmm import MVNMixtureModel
 from .explogreg import Regression
 from .run import run_inference
-from .simulations import Simulate, generate_synthetic_data
+from .simulations import Simulate
